@@ -1,5 +1,5 @@
-if (file.exists('Data')==FALSE) {
-  dir.create("Data")
+if (file.exists('Data_test')==FALSE) {
+  dir.create("Data_test")
 }
 
 test_that("Checks arguments are correctly filled in", {
@@ -11,13 +11,13 @@ test_that("Checks arguments are correctly filled in", {
     error = TRUE)
   expect_snapshot(
     json_to_parquet(
-      path_to_parquet = "Data"
+      path_to_parquet = "Data_test"
     ),
     error = TRUE)
   expect_snapshot(
     json_to_parquet(
       path_to_json = system.file("extdata","iris.json",package = "parquetize"),
-      path_to_parquet = "Data",
+      path_to_parquet = "Data_test",
       format = "xjson"
     ),
     error = TRUE)
@@ -27,7 +27,7 @@ test_that("Checks message is displayed with json file", {
   expect_snapshot(
     json_to_parquet(
       path_to_json = system.file("extdata","iris.json",package = "parquetize"),
-      path_to_parquet = "Data"
+      path_to_parquet = "Data_test"
     )
   )
 })
@@ -36,7 +36,7 @@ test_that("Checks message is displayed with ndjson file", {
   expect_snapshot(
     json_to_parquet(
       path_to_json = system.file("extdata","iris.ndjson",package = "parquetize"),
-      path_to_parquet = "Data",
+      path_to_parquet = "Data_test",
       format = "ndjson"
     )
   )
@@ -47,7 +47,7 @@ test_that("Checks message is displayed with by adding partition and partitioning
   expect_snapshot(
     json_to_parquet(
       path_to_json = system.file("extdata","iris.json",package = "parquetize"),
-      path_to_parquet = "Data",
+      path_to_parquet = "Data_test",
       partition = "yes",
       partitioning =  c("Species")
     )
