@@ -1,5 +1,5 @@
-if (file.exists('Data')==FALSE) {
-  dir.create("Data")
+if (file.exists('Data_test')==FALSE) {
+  dir.create("Data_test")
 }
 
 test_that("Checks arguments are correctly filled in", {
@@ -11,23 +11,16 @@ test_that("Checks arguments are correctly filled in", {
   )
   expect_snapshot(
     sqlite_to_parquet(
-      path_to_parquet = "Data"
+      path_to_parquet = "Data_test"
     ),
     error = TRUE
   )
+})
+
+test_that("Check if extension used in path_to_sqlite is correct", {
   expect_snapshot(
     sqlite_to_parquet(
-      path_to_sqlite = system.file("extdata","iris.sqlit",package = "parquetize"),
-      table_in_sqlite = "iris",
-      path_to_parquet = "Data"
-    ),
-    error = TRUE
-  )
-  expect_snapshot(
-    sqlite_to_parquet(
-      path_to_sqlite = system.file("extdata","iris.sqlite",package = "parquetize"),
-      table_in_sqlite = "mtcars",
-      path_to_parquet = "Data"
+      path_to_sqlite = system.file("extdata","iris.sqliteee",package = "parquetize")
     ),
     error = TRUE
   )
@@ -38,7 +31,7 @@ test_that("Checks message is displayed with sqlite file", {
     sqlite_to_parquet(
       path_to_sqlite = system.file("extdata","iris.sqlite",package = "parquetize"),
       table_in_sqlite = "iris",
-      path_to_parquet = "Data"
+      path_to_parquet = "Data_test"
     )
   )
 })
@@ -49,7 +42,7 @@ test_that("Checks message is displayed with by adding partition and partitioning
     sqlite_to_parquet(
       path_to_sqlite = system.file("extdata","iris.sqlite",package = "parquetize"),
       table_in_sqlite = "iris",
-      path_to_parquet = "Data",
+      path_to_parquet = "Data_test",
       partition = "yes",
       partitioning =  c("Species")
     )
